/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's 2019 What Does *
* Federal Economic Crime Really Look Like report file and create a SAS dataset.          *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_Economic_Report_2019_Public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_Economic_Report_2019_Public ;

DATA library.&dataset ;
INFILE datafile LRECL=78;
INPUT
   SENSPLT0  1-6            USSCIDN  7-13            AGE  14-15            
   BOOKERCD  16-17          CIRCDIST  18-19          MONCIRC  20-21        
   MONRACE  22              MONSEX  23               NEWCIT  24            
   NEWEDUC  25              NEWRACE  26              SENTIMP  27           
   XCRHISSR  28             YEARS  29                AMENDYR  30-33        
   ABUSHI  34               ADJ_BHI  35-36           ADJ_CHI  37           
   ADJ_DHI  38              ADJ_EHI  39              ADJ_FHI  40           
   ADJ_GHI  41              ADJ_HHI  42              ADJ_IHI  43           
   ADJ_JHI  44              ADJ_KHI  45-46           ADJ_LHI  47           
   ADJ_MHI  48              ADJ_NHI  49              ADJ_OHI  50           
   ADJ_PHI  51-52           ADJ_QHI  53-54           ADJ_RHI  55           
   ADJ_SHI  56              AGGROLHI  57             MITROLHI  58-59       
   LOSSHI  60-69            CODEMEYN  70             sophisticated_l $ 71  
   fy  72-75                ADJ_THI  76              econ_descending  77-78
 ;                       

LABEL
   USSCIDN = "USSCIDN"
   MONRACE = "MONRACE"
   MONSEX = "MONSEX"
   XCRHISSR = "XCRHISSR"
   AMENDYR = "AMENDYR"
;

LENGTH
   USSCIDN 6                AGE 3                    BOOKERCD 3            
   CIRCDIST 3               MONCIRC 3                MONRACE 3             
   MONSEX 3                 NEWCIT 3                 NEWEDUC 3             
   NEWRACE 3                SENTIMP 3                XCRHISSR 3            
   YEARS 3                  AMENDYR 4                ABUSHI 3              
   ADJ_BHI 3                ADJ_CHI 3                ADJ_DHI 3             
   ADJ_EHI 3                ADJ_FHI 3                ADJ_GHI 3             
   ADJ_HHI 3                ADJ_IHI 3                ADJ_JHI 3             
   ADJ_KHI 3                ADJ_LHI 3                ADJ_MHI 3             
   ADJ_NHI 3                ADJ_OHI 3                ADJ_PHI 3             
   ADJ_QHI 3                ADJ_RHI 3                ADJ_SHI 3             
   AGGROLHI 3               MITROLHI 3               CODEMEYN 3            
   fy 4                     ADJ_THI 3                econ_descending 3 ;

 

RUN ;
